Turberfield Utility library — Turberfield utilities guide 0.40.0

# Turberfield utilities guide 0.40.0

## Turberfield Utility library

Turberfield is a framework for discrete event simulations and turn-based games.

The API may change as the project proceeds. At this early stage you should only use the latest release; it may not be compatible with previous versions.

If you’ve spotted a bug in Turberfield, please let me know so I can fix it. If you think Turberfield lacks a feature, you can help drive development by describing your Use Case.

In either event, please leave a message on the project’s message board.

# Turberfield Utility library

Author:

  tundish

Copyright:

  2019 D Haynes

Licence:

  GNU General Public License

- 1. Object serialisation
- 2. Interprocess queues
- 3. Spacial coordinates
- 4. Calculating motion
- 5. Agent-oriented programming

- Index